@@ -22,6 +22,7 @@ from ._standards.sic import SIC, SIC_to_NAICS2017
 from ._standards.skd2002 import SKD2002, SKD2002_to_NACE2, SKD2002_to_SKD2008
 from ._standards.skd2008 import SKD2008, SKD2008_to_SKD2002
 from ._standards.skis2010 import SKIS2010
+from ._standards.ssic2020 import SSIC2020, SSIC2020_to_ISIC4
 from ._standards.tsic2552 import TSIC2552, TSIC2552_to_ISIC3
 from .types import ComposedGraph, Standards
 
@@ -51,5 +52,6 @@ ToISIC4 = ComposedGraph(
         CAEM2005_to_ISIC3,
         SBI2008_to_NACE2,
         SIC_to_NAICS2017,
+        SSIC2020_to_ISIC4,
     ],
 )
