@@ -59,6 +59,7 @@ SKD2002 = Standard(
         Classification("15.510", "Mlekarstvo in sirarstvo, proizvodnja mlečnih izdelkov", Category.CLASS),
         Classification("15.520", "Proizvodnja sladoleda", Category.CLASS),
         Classification("15.610", "Mlinarstvo", Category.CLASS),
+        Classification("15.620", "Proizvodnja škroba in škrobnih izdelkov", Category.CLASS),
         Classification("15.710", "Proizvodnja krmil", Category.CLASS),
         Classification("15.720", "Proizvodnja hrane za hišne živali", Category.CLASS),
         Classification("15.810", "Proizvodnja kruha, svežega peciva in slaščic", Category.CLASS),
@@ -83,6 +84,7 @@ SKD2002 = Standard(
         Classification("16.000", "Proizvodnja tobačnih izdelkov", Category.CLASS),
         Classification("17.100", "Priprava in predenje tekstilnih vlaken", Category.CLASS),
         Classification("17.20", "Tkanje tekstilij", Category.CLASS),
+        Classification("17.200", "Tkanje tekstilij", Category.CLASS),
         Classification("17.300", "Plemenitenje tekstilij", Category.CLASS),
         Classification("17.400", "Proizvodnja tekstilnih izdelkov, razen oblačil", Category.CLASS),
         Classification("17.510", "Proizvodnja preprog in talnih oblog", Category.CLASS),
@@ -112,6 +114,7 @@ SKD2002 = Standard(
         Classification("20.300", "Stavbno mizarstvo", Category.CLASS),
         Classification("20.400", "Proizvodnja lesene embalaže", Category.CLASS),
         Classification("20.510", "Proizvodnja drugih izdelkov iz lesa", Category.CLASS),
+        Classification("20.520", "Proizvodnja izdelkov iz plute, slame in protja", Category.CLASS),
         Classification("21.110", "Proizvodnja vlaknin", Category.CLASS),
         Classification("21.120", "Proizvodnja papirja in kartona", Category.CLASS),
         Classification(
@@ -537,6 +540,8 @@ SKD2002 = Standard(
             "Dejavnost potovalnih agencij in organizatorjev potovanj; s turizmom povezane dejavnosti",
             Category.CLASS,
         ),
+        Classification("63.400", "Dejavnost drugih prometnih agencij", Category.CLASS),
+        Classification("64.110", "Javna pošta", Category.CLASS),
         Classification("64.120", "Kurirska dejavnost, razen javne pošte", Category.CLASS),
         Classification("64.200", "Telekomunikacije", Category.CLASS),
         Classification("65.110", "Dejavnost centralne banke", Category.CLASS),
